updateInternetAccess method

void updateInternetAccess(
  1. bool hasInternetAccess
)

Updates the local node's internet access status in the background sync engine. The new status will be included in the next sync payload.

Implementation

void updateInternetAccess(bool hasInternetAccess) {
  if (getIt.isRegistered<AirpassSyncEngine>()) {
    getIt<AirpassSyncEngine>().localHasInternetAccess = hasInternetAccess;
  }
}