GroupSubscriptionLimitException class

Thrown when subscribing to a group would cause the encoded endpoint name to exceed the 131-byte Nearby Connections API limit.

Implemented types

Constructors

GroupSubscriptionLimitException({required int currentLength, required int maxLength, required String attemptedGroupId, required List<String> currentGroupIds})
const

Properties

attemptedGroupId String
final
currentGroupIds List<String>
final
currentLength int
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited