$AirpassDatabaseManager class

Constructors

$AirpassDatabaseManager(_$AirpassDatabase _db)

Properties

groups $$GroupsTableTableManager
no setter
hashCode int
The hash code for this object.
no setterinherited
messageDeliveries $$MessageDeliveriesTableTableManager
no setter
messages $$MessagesTableTableManager
no setter
nodes $$NodesTableTableManager
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited