createAlias method

  1. @override
$GroupsTable createAlias(
  1. String alias
)

Creates an alias of this table or view that will write the name alias when used in a query.

Implementation

@override
$GroupsTable createAlias(String alias) {
  return $GroupsTable(attachedDatabase, alias);
}