createAlias method
Creates an alias of this table or view that will write the name alias
when used in a query.
Implementation
@override
$NodesTable createAlias(String alias) {
return $NodesTable(attachedDatabase, alias);
}
Creates an alias of this table or view that will write the name alias
when used in a query.
@override
$NodesTable createAlias(String alias) {
return $NodesTable(attachedDatabase, alias);
}