watchKnownNodes method
Watches all known nodes, ordered by most recently seen. Use this to build a live routing table view in the UI.
Implementation
Stream<List<Node>> watchKnownNodes() {
return (select(nodes)..orderBy([(t) => OrderingTerm.desc(t.lastSeen)]))
.watch();
}