Group class

Constructors

Group({required String groupId, required String displayName, required int discoveredAt, required int lastSeenAt, required int memberCount, required bool isSubscribed, String? metadata})
const
Group.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

discoveredAt int
Epoch milliseconds when this group was first discovered.
final
displayName String
Human-readable display name for the group. May be the same as groupId when first discovered; can be updated later.
final
groupId String
Unique group identifier string (e.g., 'protest-2026', 'aid-sector-5').
final
hashCode int
The hash code for this object.
no setteroverride
isSubscribed bool
Whether the local node is subscribed (actively participating) in this group. Only one group can be active at a time for NodeRole.group nodes.
final
lastSeenAt int
Epoch milliseconds of the last time a node advertising this group was encountered (directly or via gossip).
final
memberCount int
Number of distinct nodes currently known to belong to this group. Updated during sync merges for UI display (e.g., "12 members").
final
metadata String?
Extensible JSON blob for future metadata (e.g., description, icon).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? groupId, String? displayName, int? discoveredAt, int? lastSeenAt, int? memberCount, bool? isSubscribed, Value<String?> metadata = const Value.absent()}) Group
copyWithCompanion(GroupsCompanion data) Group
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) GroupsCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override