isSubscribed property
Whether the local node is subscribed (actively participating) in this group. Only one group can be active at a time for NodeRole.group nodes.
Implementation
final bool isSubscribed;
Whether the local node is subscribed (actively participating) in this group. Only one group can be active at a time for NodeRole.group nodes.
final bool isSubscribed;