lastSeenAt property
Epoch milliseconds of the last time a node advertising this group was encountered (directly or via gossip).
Implementation
final int lastSeenAt;
Epoch milliseconds of the last time a node advertising this group was encountered (directly or via gossip).
final int lastSeenAt;