MessageDeliveriesCompanion class

Constructors

MessageDeliveriesCompanion({Value<String> messageId = const Value.absent(), Value<String> peerNodeId = const Value.absent(), Value<int> deliveredAt = const Value.absent(), Value<int> rowid = const Value.absent()})
const
MessageDeliveriesCompanion.insert({required String messageId, required String peerNodeId, required int deliveredAt, Value<int> rowid = const Value.absent()})

Properties

deliveredAt → Value<int>
final
hashCode int
The hash code for this object.
no setterinherited
messageId → Value<String>
final
peerNodeId → Value<String>
final
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<String>? messageId, Value<String>? peerNodeId, Value<int>? deliveredAt, Value<int>? rowid}) MessageDeliveriesCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? messageId, Expression<String>? peerNodeId, Expression<int>? deliveredAt, Expression<int>? rowid}) → Insertable<MessageDelivery>