MessageDelivery class

Constructors

MessageDelivery({required String messageId, required String peerNodeId, required int deliveredAt})
const
MessageDelivery.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

deliveredAt int
Epoch milliseconds when the delivery occurred.
final
hashCode int
The hash code for this object.
no setteroverride
messageId String
The message that was delivered.
final
peerNodeId String
The peer node that received this message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? messageId, String? peerNodeId, int? deliveredAt}) MessageDelivery
copyWithCompanion(MessageDeliveriesCompanion data) MessageDelivery
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) MessageDeliveriesCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override