toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return (StringBuffer('MessagesCompanion(')
        ..write('messageId: $messageId, ')
        ..write('senderId: $senderId, ')
        ..write('targetId: $targetId, ')
        ..write('payload: $payload, ')
        ..write('status: $status, ')
        ..write('createdAt: $createdAt, ')
        ..write('ttl: $ttl, ')
        ..write('signature: $signature, ')
        ..write('mediaType: $mediaType, ')
        ..write('mediaFileName: $mediaFileName, ')
        ..write('mediaMimeType: $mediaMimeType, ')
        ..write('mediaFileSize: $mediaFileSize, ')
        ..write('mediaHash: $mediaHash, ')
        ..write('mediaLocalPath: $mediaLocalPath, ')
        ..write('mediaAvailability: $mediaAvailability, ')
        ..write('mediaThumbnail: $mediaThumbnail, ')
        ..write('rowid: $rowid')
        ..write(')'))
      .toString();
}