hopCount property
How many relay hops away this node was last known to be. 0 = direct encounter, 1 = one hop away, etc.
Implementation
final int hopCount;
How many relay hops away this node was last known to be. 0 = direct encounter, 1 = one hop away, etc.
final int hopCount;