lastSeen property
Epoch milliseconds of the last time this node was encountered (directly or via gossip).
Implementation
final int lastSeen;
Epoch milliseconds of the last time this node was encountered (directly or via gossip).
final int lastSeen;