NodesCompanion class

Constructors

NodesCompanion({Value<String> nodeId = const Value.absent(), Value<int> role = const Value.absent(), Value<String?> groupId = const Value.absent(), Value<int> lastSeen = const Value.absent(), Value<int> hopCount = const Value.absent(), Value<String?> displayName = const Value.absent(), Value<int?> batteryLevel = const Value.absent(), Value<bool> hasInternetAccess = const Value.absent(), Value<String?> metadata = const Value.absent(), Value<int> rowid = const Value.absent()})
const
NodesCompanion.insert({required String nodeId, Value<int> role = const Value.absent(), Value<String?> groupId = const Value.absent(), required int lastSeen, Value<int> hopCount = const Value.absent(), Value<String?> displayName = const Value.absent(), Value<int?> batteryLevel = const Value.absent(), Value<bool> hasInternetAccess = const Value.absent(), Value<String?> metadata = const Value.absent(), Value<int> rowid = const Value.absent()})

Properties

batteryLevel → Value<int?>
final
displayName → Value<String?>
final
groupId → Value<String?>
final
hashCode int
The hash code for this object.
no setterinherited
hasInternetAccess → Value<bool>
final
hopCount → Value<int>
final
lastSeen → Value<int>
final
metadata → Value<String?>
final
nodeId → Value<String>
final
role → Value<int>
final
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<String>? nodeId, Value<int>? role, Value<String?>? groupId, Value<int>? lastSeen, Value<int>? hopCount, Value<String?>? displayName, Value<int?>? batteryLevel, Value<bool>? hasInternetAccess, Value<String?>? metadata, Value<int>? rowid}) NodesCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? nodeId, Expression<int>? role, Expression<String>? groupId, Expression<int>? lastSeen, Expression<int>? hopCount, Expression<String>? displayName, Expression<int>? batteryLevel, Expression<bool>? hasInternetAccess, Expression<String>? metadata, Expression<int>? rowid}) → Insertable<Node>