SyncNodeEntry class

A node entry within a SyncPayload.

Constructors

SyncNodeEntry({required String nodeId, required int role, String? groupId, required int lastSeen, required int hopCount, String? displayName, int? batteryLevel, bool hasInternetAccess = false})
const
SyncNodeEntry.fromJson(Map<String, dynamic> json)
factory

Properties

batteryLevel int?
final
displayName String?
final
groupId String?
final
hashCode int
The hash code for this object.
no setterinherited
hasInternetAccess bool
final
hopCount int
final
lastSeen int
final
nodeId String
final
role int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited