EndpointMetadata class

Decoded metadata extracted from an endpoint name string.

Constructors

EndpointMetadata({required int protocolVersion, required NodeRole role, required List<String> groupIds, required String nodeIdPrefix, String? microMessage})
const

Properties

groupIds List<String>
All groups the remote node is subscribed to. Contains '*' if the node is ungrouped or global.
final
hashCode int
The hash code for this object.
no setterinherited
microMessage String?
Optional micro-message broadcast connectionlessly via the endpoint name. Null if no micro-message is being broadcast.
final
nodeIdPrefix String
Prefix of the remote node's UUID (first 8 characters).
final
primaryGroupId String
Convenience: returns the first group ID (for backward compatibility). Returns '*' if ungrouped.
no setter
protocolVersion int
Protocol version of the remote peer.
final
role NodeRole
The remote node's mesh role.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited