EndpointNameTooLongException class

Thrown when the encoded endpoint name exceeds the 131-byte limit.

Implemented types

Constructors

EndpointNameTooLongException({required int actualLength, required int maxLength, required String encoded})
const

Properties

actualLength int
final
encoded String
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited