models/media_type library
Airpass Protocol — Media Type Enum
Classifies the type of media attached to a store-and-forward message. Text-only messages use MediaType.text (the default).
Enums
- MediaType
- The type of media content attached to a message.
Airpass Protocol — Media Type Enum
Classifies the type of media attached to a store-and-forward message. Text-only messages use MediaType.text (the default).