MessageSigner class
Signs and verifies Airpass messages using HMAC-SHA256.
Constructors
- MessageSigner({required String nodeId})
- Creates a signer using the node's UUID as the signing key.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signMessage(
{required String messageId, required String senderId, required String targetId, required Uint8List payload, required int createdAt}) → String - Signs a message and returns the hex-encoded HMAC-SHA256 signature.
-
toString(
) → String -
A string representation of this object.
inherited
-
verifySignature(
{required String messageId, required String senderId, required String targetId, required Uint8List payload, required int createdAt, required String signature}) → bool - Verifies that a message's signature is valid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited